# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-19 12:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0014_remove_userprofile_is_leave'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userleaverecord',
            options={'ordering': ['-created_at'], 'permissions': (('update_type_cancel', '\u53ef\u4ee5\u9500\u5047'), ('change_check', '\u53ef\u4ee5\u5ba1\u6838\u7528\u6237\u7684\u8bf7\u5047'))},
        ),
    ]
