{% extends "bee_django_user/base.html" %}
{% load bee_django_user_filter %}
{% block content %}
    {% include 'bee_django_user/logo.html' %}
    {% include 'bee_django_user/nav.html' %}
    {% include 'bee_django_user/messages.html' %}
    <h4>详情</h4>
    {% include 'bee_django_user/leave/_detail_info.html' %}
{% endblock %}