# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-26 09:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0006_userleaverecord'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userleaverecord',
            name='old_expire',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u539f\u7ed3\u8bfe\u65e5\u671f'),
        ),
        migrations.AlterField(
            model_name='userleaverecord',
            name='type',
            field=models.IntegerField(choices=[(1, '\u8bf7\u5047'), (2, '\u9500\u5047'), (3, '\u5ef6\u671f')], default=1, verbose_name='\u7c7b\u578b'),
        ),
    ]
