# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-02-19 14:13
from __future__ import unicode_literals

from django.db import migrations
import imagekit.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0015_auto_20181219_2057'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='avatar',
            field=imagekit.models.fields.ProcessedImageField(blank=True, default='avatars/default.jpg', null=True, upload_to='avatars', verbose_name='\u5934\u50cf'),
        ),
    ]
